@@ -6,5 +6,7 @@ from composable.pipeable import (
 
 from composable.utility import pipeable_all_in_module
 import toolz.curried.operator as operator
+import toolz.curried as from_toolz
 
-pipeable_all_in_module(operator)
\ No newline at end of file
+pipeable_all_in_module(operator)
+pipeable_all_in_module(from_toolz)
\ No newline at end of file
